Learn R Programming

reutils (version 0.2.1)

esummary: esummary - downloading Document Summaries

Description

esummary performs calls to the NCBI ESummary utility to retrieve document summaries (DocSums) for a list of primary UIDs or for a set of UIDs stored in the user's web environment (using the Entrez History server).

Usage

esummary(uid, db = NULL, retstart = 1, retmax = 10000, querykey = NULL,
  webenv = NULL, retmode = "xml", version = "2.0")

Arguments

uid
(Required) List of UIDs provided either as a character vector, as an esearch or elink object, or by reference to a Web Environment and a query key obtained directly from objects returned by previous calls to
db
(Required only when id is a character vector of UIDs) Database from which to retrieve DocSums.
retstart
Numeric index of the first DocSum to be retrieved (default: 1).
retmax
Total number of DocSums from the input set to be retrieved (maximum: 10,000).
querykey
An integer specifying which of the UID lists attached to a user's Web Environment will be used as input to efetch. (Usually obtained drectely from objects returned by previous esearch,
webenv
A character string specifying the Web Environment that contains the UID list. (Usually obtained directely from objects returned by previous esearch, epost or <
retmode
Retrieval mode. (default: 'xml', alternative: 'json')
version
If "2.0" esummary will retrieve version 2.0 ESummary XML output.

Value

  • An esummary object.

Details

See the official online documentation for NCBI's http://www.ncbi.nlm.nih.gov/books/NBK25499//#chapter4.ESummary{EUtilities} for additional information.

See Also

content, getUrl, getError, database.

Examples

Run this code
## Retrieve the Document Summary information for a set of
## UIDs frome the Gene datanase.
ds <- esummary(c("828392", "790", "470338"), "gene")
ds

## parse the XML into a data frame
df <- content(ds, "parsed")
df

## use XPath expressions to extract nodes of interest
ds['//TaxID']

Run the code above in your browser using DataLab