A list containing a set of links as returned by a call to elink.
Each element of the list is a character vector of UIDs of class
"entrez_link" with three attributes:
[object Object],[object Object],[object Object]
Arguments
Details
An "entrez_linkset" has two global attributes:
[object Object],[object Object]